# Django Filepond Widget


## License

You can freely use this project without limitations.
More specificallly, this project is freely licenced under the "Unlicense".
See the LICENSE file for more information.

Note that django, django_drf_filepond, filepond and js-cookie are licensed under
different licences.
